Heatmap

Struct Heatmap 

pub struct Heatmap { /* private fields */ }
A heatmap.

Implementations

Source

impl Heatmap

pub fn new(values: Vec<f64>, cols: usize) -> Self

Create a 2D heatmap. Will automatically infer number of rows.

  • values contains magnitude of each tile. The alignment is row by row.
  • cols is the number of columns (i.e. the length of each row).
  • values.len() should be a multiple of cols.

Example: To display this

| – | – | | 0.0 | 0.1 | | 0.3 | 0.4 |

pass values = vec![0.0, 0.1, 0.3, 0.4] and cols = 2.

If parameters are invalid (e.g., cols is zero, values is empty, or values.len() is not divisible by cols), an empty heatmap is created.

pub fn resolution(self, resolution: usize) -> Self

Set the resolution of the color palette.

Higher resolution means smoother color transitions. Default is 128.

pub fn palette(self, base_colors: &[Color32]) -> Self

Set color palette by specifying base colors from low to high

pub fn range(self, min: f64, max: f64) -> Self

Specify custom range of values to map onto color palette.

  • min and everything smaller will be the first color on the color palette.
  • max and everything greater will be the last color on the color palette.
pub fn formatter(self, formatter: Box<dyn Fn(f64) -> String>) -> Self

Add a custom way to format an element. Can be used to display a set number of decimals or custom labels.

pub fn custom_mapping(self, custom_mapping: Box<dyn Fn(f64) -> Color32>) -> Self

Add a custom way to map values to a color.

pub fn show_labels(self, en: bool) -> Self

Show labels for each tile in heatmap. Defaults to ‘true’

pub fn at(self, pos: PlotPoint) -> Self

Place lower left corner of heatmap at pos. Default is (0.0, 0.0)

pub fn name(self, name: impl ToString) -> Self

Name of this heatmap.

This name will show up in the plot legend, if legends are turned on. Multiple heatmaps may share the same name, in which case they will also share an entry in the legend.

pub fn tile_size(self, x: f32, y: f32) -> Self

Manually set width and height of tiles in plot coordinate space.

pub fn size(self, x: f32, y: f32) -> Self

Set size of heatmap in plot coordinate space. Will adjust the heatmap tile size in plot coordinate space.

pub fn highlight(self, highlight: bool) -> Self

Highlight all plot elements.